
"""
This module contains a function for generating random names in Portuguese.
"""
import random 
from typing import Optional
from names import men_names, women_names, surnames

class Person:
    def __init__(self, first_name: str, last_name: str, gender: int) -> None:
        self.first_name = first_name
        self.last_name = last_name
        self.gender = gender

    def __str__(self) -> str:
        return f"{self.first_name} {self.last_name}"

def generate_name(gender: Optional[int] = None) -> str:
    """
    Generates a random name in Portuguese.

    Parameters:
        gender (int): The gender of the name to generate. 0 for male, 1 for female.

    Returns:
        Name: An object containing the generated name.
    """
    try:
        if not gender:
            gender = random.randint(0, 1)
        firts_name = random.choices(men_names if gender == 0 else women_names, k=1)[0]
        last_name = random.choices(surnames, k=1)[0]
        return Person(firts_name, last_name, gender)
    except ValueError:
        return "Invalid gender parameter. Please specify 0 for male or 1 for female."
    except IndexError:
        return "An error occurred while accessing the list of names or surnames."
    except Exception as e:
        return f"An error occurred: {e}"



women_names = [
    "Cíntia",
    "Livia",
    "Paula",
    "Josiane",
    "Mirian",
    "Yeda",
    "Maria",
    "Vívian",
    "Francielle",
    "Wendy",
    "Mariana",
    "Soraya",
    "Mirella",
    "Fabiana",
    "Valeska",
    "Nina",
    "Danielle",
    "Roseli",
    "Agatha",
    "Bella",
    "Ediane",
    "Melanie",
    "Mirela",
    "Anna",
    "Olívia",
    "Luiza",
    "Laura",
    "Gigi",
    "Monique",
    "Gislaine",
    "Lena",
    "Lúcia",
    "Brenda",
    "Samara",
    "Cássia",
    "Luciana",
    "Lili",
    "Raíssa",
    "Clotilde",
    "Rafaela",
    "Suellen",
    "Sarah",
    "Sandra",
    "Bernadete",
    "Suely",
    "Kiara",
    "Diana",
    "Leonara",
    "Cristina",
    "Tainá",
    "Leni",
    "Maísa",
    "Evelyn",
    "Kamilly",
    "Luana",
    "Lorena",
    "Sophie",
    "Lavinia",
    "Maíra",
    "Eulália",
    "Valéria",
    "Selma",
    "Vanda",
    "Sofia",
    "Cristiane",
    "Renata",
    "Tina",
    "Dara",
    "Ana",
    "Talita",
    "Celeste",
    "Heloísa",
    "Bete",
    "Alicia",
    "Adrielle",
    "Jenny",
    "Cláudia",
    "Abigail",
    "Tânia",
    "Vânia",
    "Zilda",
    "Milene",
    "Albina",
    "Mel",
    "Amanda",
    "Luara",
    "Zulmira",
    "Leticia",
    "Clarice",
    "Joelma",
    "Vera",
    "Violeta",
    "Aparecida",
    "Gabrielle",
    "Suzana",
    "Dilma",
    "Alessandra",
    "Fernanda",
    "Emilly",
    "Clara",
    "Núbia",
    "Isabela",
    "Zara",
    "Ingrid",
    "Márcia",
    "Olivia",
    "Gisele",
    "Raquel",
    "Marta",
    "Sílvia",
    "Keyla",
    "Ângela",
    "Ísis",
    "Edilene",
    "Isadora",
    "Júlia",
    "Sônia",
    "Valquíria",
    "Rose",
    "Nicole",
    "Nayara",
    "Elizabete",
    "Meire",
    "Heloisa",
    "Luzimara",
    "Maite",
    "Rosângela",
    "Adriana",
    "Sâmia",
    "Carla",
    "Eliomar",
    "Magali",
    "Tainara",
    "Teresa",
    "Isaiane",
    "Juliana",
    "Raiane",
    "Bruna",
    "Mikaella",
    "Andréia",
    "Cármen",
    "Manuela",
    "Ivete",
    "Léia",
    "Lígia",
    "Samanta",
    "Eduarda",
    "Stephany",
    "Mayara",
    "Rosilda",
    "Rute",
    "Margarida",
    "Christie",
    "Hellen",
    "Karina",
    "Julia",
    "Kátia",
    "Jandira",
    "Eunice",
    "Ariana",
    "Eleriane",
    "Úrsula",
    "Yolanda",
    "Ariel",
    "Angélica",
    "Taís",
    "Gabriela",
    "Charlene",
    "Fabíola",
    "Lidiane",
    "Érica",
    "Marli",
    "Gabrielly",
    "Sara",
    "Suzy",
    "Samila",
    "Joyce",
    "Lívia",
    "Helena",
    "Marcela",
    "Jussara",
    "Catarina",
    "Rosa",
    "Cecília",
    "Olímpia",
    "Ivanete",
    "Olga",
    "Célia",
    "Tatiana",
    "Velma",
    "Camila",
    "Cecilia",
    "Isabelly",
    "Shirley",
    "Daniela",
    "Eleonora",
    "Neila",
    "Marilúcia",
    "Lais",
    "Felícia",
    "Patrícia",
    "Mariane",
    "Leila",
    "Karin",
    "Cleuza",
    "Eliane",
    "Nair",
    "Quitéria",
    "Rita",
    "Marcielle",
    "Joana",
    "Vitória",
    "Rebeca",
    "Jaqueline",
    "Yasmin",
    "Hilda",
    "Lilian",
    "Vanessa",
    "Stella",
    "Matilde",
    "Tatiane",
    "Quésia",
    "Marciane",
    "Wilma",
    "Terezinha",
    "Guiomar",
    "Esther",
    "Selena",
    "Lina",
    "Thaís",
    "Lana",
    "Amália",
    "Giovanna",
    "Dina",
    "Janaína",
    "Liane",
    "Emanuella",
    "Poliana",
    "Bianca",
    "Telma",
    "Emanuelly",
    "Cícera",
    "Sophia",
    "Alice",
    "Cibele",
    "Alana",
    "Thaíssa",
    "Sheila",
    "Damares",
    "Regina",
    "Rosimeire",
    "Solange",
    "Tábata",
    "Arlete",
    "Zuleide",
    "Simone",
    "Amélia",
    "Arilda",
    "Anne",
    "Flávia",
    "Marielle",
    "Zenaide",
    "Pietra",
    "Valdirene",
    "Eva",
    "Milena",
    "Barbara",
    "Josilda",
    "Luna",
    "Isabella",
    "Elisete",
    "Laila",
    "Mayra",
    "Eloah",
    "Lara",
    "Celina",
    "Kelly",
    "Priscila",
    "Itamara",
    "Luzinete",
    "Marlene",
    "Genir",
    "Janete",
    "Sabrina",
    "Luzia",
    "Graziele",
    "Roberta",
    "Maysa",
    "Melissa",
    "Natalia",
    "Gilmara",
    "Flaviana",
    "Ivone",
    "Denise",
    "Viviane",
    "Eloá",
    "Bárbara",
    "Xilena",
    "Elisa",
    "Valentina",
    "Aline",
    "Lisa",
    "Wanda",
    "Marina",
    "Beatriz",
    "Verônica",
    "Jeniffer",
    "Laís",
    "Margarete",
    "Elaine",
    "Larissa",
    "Daiane",
    "Isis",
    "Carolina",
    "Isabel",
    "Jéssica",
    "Quênia",
    "Madalena",
    "Suzanne",
    "Natália",
    "Mônica",
    "Berenice",
    "Fátima",
    "Alexia",
    "Michele",
    "Elisângela",
    "Mara",
    "Andressa",
    "Nádia",
    "Susan",
    "Otávia",
    "Rosana",
    "Walderice",
    "Paulínia",
    "Caroline",
]

surnames = [
    "De Iglesias",
    "De Paiva",
    "Henrique Da Costa",
    "Hugo Costa",
    "De Cerqueira",
    "Deltreggia Sartori",
    "Miranda",
    "Luiz Campos",
    "Figueira",
    "Mello",
    "Rossi",
    "Clara Farias",
    "Drummond",
    "Fortes",
    "De Cardozo",
    "Malta",
    "Weber",
    "São Pedro",
    "Alice Farias",
    "Luiza Costela",
    "De Rezende",
    "Fernanda Pires",
    "De Santana",
    "Torres",
    "De Novais",
    "Lucas Silveira",
    "Beatriz Cardoso",
    "De Uchôa",
    "Cecilia Barbosa",
    "De Albuquerque",
    "Lucca Sales",
    "De Lacerda",
    "Barboza",
    "Arantes",
    "Borges",
    "Do Maranhão",
    "Sophia Pinto",
    "De Vasconcelos",
    "Penedo",
    "Coelho",
    "Espada",
    "Martins",
    "Prates",
    "Pereira",
    "Gabriel Cunha",
    "Gabriel Das Neves",
    "Paranhos",
    "De Leite",
    "De Braga",
    "Henrique Melo",
    "Gutierrez",
    "Carvalho",
    "De Lemos",
    "Da Conceição",
    "De Peres",
    "Eduarda Viana",
    "Barros",
    "De Martins",
    "De Nogueira",
    "Da Paixão",
    "De Angola",
    "Paula",
    "De Padilha",
    "Alice Cardoso",
    "Guilherme Costa",
    "Julia Pires",
    "Da Paraíba",
    "Gusmão",
    "De Araújo",
    "Rocha",
    "De Paula",
    "Henrique Goncalves",
    "Fogaca",
    "De Mendonça",
    "De Fernandes",
    "Peres",
    "Barbosa",
    "Eduardo Araujo",
    "De Pinheiro",
    "Fernanda Rezende",
    "Miguel Novaes",
    "Da Silva",
    "Mineiro",
    "Luiz Da Cruz",
    "Goncalves",
    "De Amorim",
    "Angola",
    "Dias",
    "De Melo",
    "De Tavares",
    "De Menezes",
    "Pedro Porto",
    "Hugo Souza",
    "De Assis",
    "Brandão",
    "Trindade",
    "Branco",
    "Portugal",
    "Arruda",
    "Castelo Branco",
    "Da Cunha",
    "Da Graça",
    "Mourão",
    "Miguel Martins",
    "De Pacheco",
    "Câmara",
    "Antunes",
    "Araujo",
    "De Coelho",
    "Do Prado",
    "Vitor Caldeira",
    "Freitas",
    "Das Neves",
    "De Viana",
    "De Drummond",
    "Cavalcante",
    "De Gusmão",
    "Alencar",
    "Alice Teixeira",
    "Preto",
    "Miguel Da Cruz",
    "Gabriel Gomes",
    "Tozetto",
    "Aguiar",
    "De Diniz",
    "Amorim",
    "De Brito",
    "Da Mota",
    "Naves",
    "Guilherme Araujo",
    "Porto",
    "De Freitas",
    "Felipe Ramos",
    "Henrique Nunes",
    "De Sá",
    "Sobral",
    "Gomes",
    "Hugo Barbosa",
    "Vitoria Peixoto",
    "Miguel Santos",
    "Fernando Barros",
    "Carolina Sales",
    "Lucca Mendes",
    "Pedro Aragao",
    "Costela",
    "De Souza",
    "Lucas Freitas",
    "Henrique Moreira",
    "Góis",
    "Ferraz",
    "Luiza Campos",
    "Magalhães",
    "Rangel",
    "De Lins",
    "Carolina Teixeira",
    "Eduardo Da Cruz",
    "De Palhares",
    "Brito",
    "Lucas Costela",
    "Jardim",
    "Paiva",
    "Da Rosa",
    "Miguel Da Mota",
    "Do Paraná",
    "Luiza Das Neves",
    "Moreira",
    "Alvim",
    "De Oliva",
    "Toledo",
    "De Ferreira",
    "Vinicius Nogueira",
    "De Silveira",
    "De Jesus",
    "Assis",
    "Vinicius Barbosa",
    "Dos Santos",
    "Guilherme Da Paz",
    "De Alvim",
    "Da Gama",
    "Couto",
    "Leão",
    "De Chaves",
    "Fonseca",
    "Salvador",
    "Simões",
    "Gustavo Da Mota",
    "Pires",
    "De Assunção",
    "Henrique Caldeira",
    "Sophia Teixeira",
    "Costa",
    "De Duarte",
    "De Peixoto",
    "Aragao",
    "Milani",
    "De Sobral",
    "Lucca Caldeira",
    "Novais",
    "Fernanda Rodrigues",
    "Gabriel Porto",
    "De Ayres",
    "Leite",
    "Ribeiro",
    "Pinheiro",
    "Maia",
    "Banhos",
    "De Farias",
    "De Camargo",
    "Do Rio",
    "Ayres",
    "De Moura",
    "Palhares",
    "Clara Das Neves",
    "De Barboza",
    "Dos Pinhais",
    "Gusmões",
    "Guimarães",
    "Osório",
    "De Borges",
    "Laura Aragao",
    "Campos",
    "Vitoria Nogueira",
    "Clara Araujo",
    "Bahia",
    "Caldeira",
    "De Barros",
    "Eduarda Nogueira",
    "Fernando Pires",
    "Julia Da Mota",
    "Eduarda Nascimento",
    "Peixoto",
    "De Arantes",
    "Albuquerque",
    "Nunes",
    "Lucca Araujo",
    "Jangada",
    "Do Vale",
    "Cardoso",
    "Mercado",
    "Gabriel Aragao",
    "De Fraga",
    "De Ramos",
    "Da Nóbrega",
    "Otavio Silva",
    "Tristão",
    "Gabriel Farias",
    "De Pereira",
    "Muniz",
    "Lima",
    "Gabriel Lopes",
    "Silveira",
    "Macedo",
    "Ximenes",
    "Sophia Castro",
    "Livia Da Paz",
    "Fernanda Lopes",
    "De Almeida",
    "Da Rocha",
    "De Espanha",
    "Da Mata",
    "Madureira",
    "Laura Azevedo",
    "De Alves",
    "De Matos",
    "De Simões",
    "De Trindade",
    "Do Amaral",
    "Negrão",
    "Azevedo",
    "De Toledo",
    "Gabriel Moura",
    "Laura Freitas",
    "Medeiros",
    "De Madureira",
    "De Noronha",
    "Gabriel Da Mata",
    "Gabriel Nascimento",
    "De Figueiredo",
    "Gabriel Campos",
    "De Junqueira",
    "De Carvalho",
    "Da Costa",
    "Mendonça",
    "Frias",
    "Monteiro",
    "De Lemes",
    "Livia Costela",
    "Rodrigues",
    "Novaes",
    "Marinho",
    "Da Conceicao",
    "De Vieira",
    "Menezes",
    "Lemes",
    "Do Espírito Santo",
    "Pacheco",
    "Pedro Monteiro",
    "Sophia Ribeiro",
    "Álvares",
    "Moraes",
    "Rezende",
    "Sampaio",
    "Da Encarnação",
    "Sanches",
    "De São Pedro",
    "De Gonçalves",
    "Weiss",
    "Henrique Farias",
    "De Vargas",
    "Henrique Jesus",
    "Vitor Da Rocha",
    "Souza",
    "Cardozo",
    "Julia Da Conceicao",
    "Salgado",
    "De Gimenes",
    "De Godoy",
    "De Campos",
    "Luiz Souza",
    "Nogueira",
    "Lucca Martins",
    "Hugo Rocha",
    "De Bragança",
    "Lucas Ferreira",
    "França",
    "Estrada",
    "Matos",
    "De Alencar",
    "De Moreira",
    "De Ortiz",
    "De Santo Antônio",
    "De Lima",
    "Vargas",
    "Igreja",
    "Assunção",
    "Miguel Sales",
    "Carolina Da Mata",
    "De Aguiar",
    "De Figueira",
    "Fontes",
    "Carolina Nunes",
    "Lucas Da Rocha",
    "Miguel Caldeira",
    "Vitoria Jesus",
    "De Pascoal",
    "Godoy",
    "Sophia Araujo",
    "De Cabral",
    "Uchôa",
    "De Teixeira",
    "De Álvares",
    "Do Amazonas",
    "Pimentel",
    "Julia Silveira",
    "Lucas Cavalcanti",
    "Abreu",
    "Britto",
    "De Salgado",
    "Rosa",
    "Sá",
    "De Magalhães",
    "Guilherme Pereira",
    "Beatriz Pereira",
    "De Ortega",
    "De Castro",
    "Duarte",
    "Eduardo Barbosa",
    "Pinto",
    "Andrade",
    "Guilherme Barros",
    "Camargo",
    "Alanoca",
    "Luiza Dias",
    "Clara Correia",
    "Castelo",
    "De Salvador",
    "Marques",
    "D'Ávila",
    "Da Serra",
    "Clara Da Cruz",
    "De Paranhos",
    "Vitoria Da Paz",
    "Paim",
    "Castro",
    "De Arruda",
    "De Alvarenga",
    "Da Cruz",
    "Correia",
    "De Oliveira",
    "Ramos",
    "Vitoria Oliveira",
    "De Maia",
    "Henrique Gomes",
    "Miguel Silva",
    "Gabriel Pereira",
    "Guedes",
    "De Azevedo",
    "Ferreira",
    "Schmidt",
    "Julia Pinto",
    "Fernandes",
    "Diniz",
    "De Osório",
    "Figueiredo",
    "Padilha",
    "De Brandão",
    "Otavio Goncalves",
    "Barroso",
    "De Monteiro",
    "De Linhares",
    "Vitor Souza",
    "Mendes",
    "Da Lira",
    "Torquato",
    "Henrique Araujo",
    "Ortega",
    "Pedro Novaes",
    "De Andrade",
    "De Macedo",
    "De Sampaio",
    "De Sales",
    "De Abreu",
    "De Gusmões",
    "Felipe Da Costa",
    "Fernanda Monteiro",
    "Dutra",
    "Vitor Gomes",
    "Machado",
    "Santana",
    "Miguel Peixoto",
    "Junqueira",
    "Munhoz",
    "Werner",
    "Cavalcanti",
    "Hugo Da Mota",
    "Pimenta",
    "Pascoal",
    "Julia Barros",
    "Soares",
    "De Lisboa",
    "Jesus",
    "Vaz",
    "Morais",
    "De Cardoso",
    "De Ferraz",
    "De Siqueira",
    "Viana",
    "Holanda",
    "Borba",
    "Buarque",
    "Guilherme Santos",
    "De Mello",
    "Vasconcelos",
    "Miguel Da Conceicao",
    "De Parreira",
    "De França",
    "Oliva",
    "Eduardo Sales",
    "Henrique Monteiro",
    "Gabriel Nunes",
    "Lucas Pinto",
    "Pinhão",
    "Silva",
    "Bezerra",
    "De Pimentel",
    "De Soares",
    "Martinez",
    "Trevisan",
    "Tavares",
    "Iglesias",
    "Alcântara",
    "Meireles",
    "De Garcia",
    "Da Luz",
    "De Malta",
    "Lopes",
    "De Meireles",
    "Araújo",
    "Fragoso",
    "Lacerda",
    "Herrera",
    "Cabral",
    "Gabriel Costela",
    "Valente",
    "De Morais",
    "Lucca Cunha",
    "De Bueno",
    "Santos",
    "De Muniz",
    "Valverde",
    "Beatriz Viana",
    "Miguel Costela",
    "Brasil",
    "De Torquato",
    "Maciel",
    "Garcia",
    "Fernanda Peixoto",
    "Julia Vieira",
    "Schneider",
    "Klein",
    "Vitor Pinto",
    "De Guimarães",
    "Siqueira",
    "Vitoria Da Rosa",
    "Vitoria Da Luz",
    "Seixas",
    "Noronha",
    "Laura Nascimento",
    "Lemos",
    "Duque",
    "Cerqueira",
    "Lucas Aragao",
    "Lins",
    "Imparato",
    "De Medeiros",
    "Clara Martins",
    "Julia Da Mata",
    "Teixeira",
    "Lucas Dias",
    "De Leão",
    "Melo",
    "Farias",
    "Freire",
    "Vinicius Da Costa",
    "Almeida",
    "Chaves",
    "Bueno",
    "Da Paz",
    "Espanha",
    "Ortiz",
    "De Holanda",
    "Lucas Das Neves",
    "De Britto",
    "De Machado",
    "Oliveira",
    "Vasco",
    "Franco",
    "Gimenes",
    "Nascimento",
    "De Antunes",
    "Gabriel Monteiro",
    "Clara Lima",
    "De Alcântara",
    "De Munhoz",
    "Parreira",
    "Dos Reis",
    "Coutinho",
    "Lisboa",
    "Queiroz",
    "Moreno",
    "De Queiroz",
    "Teles",
    "Vieira",
    "Do Piauí",
    "De Fonseca",
    "Moura",
    "Eduarda Caldeira",
    "Fernando Costa",
    "Gustavo Rocha",
    "Gonçalves",
    "Bragança",
    "Cunha",
    "Gabriel Goncalves",
    "Santo Antônio",
    "Lucas Barbosa",
    "Linhares",
    "Alves",
    "Guerra",
    "Luiza Sales",
    "Sales",
    "Fernanda Cardoso",
    "De Tozetto",
    "Gustavo Oliveira",
    "Alvarenga",
    "Otavio Da Rosa",
    "De Bezerra",
    "Gabriel Almeida",
    "De Barbosa",
    "Lucca Ribeiro",
    "Fraga",
    "Do Nascimento",
    "Rosatto",
    "De Miranda",
    "Braga",
    "Souto",
]

men_names = [
    "Gilberto",
    "Otto",
    "Damião",
    "Josiel",
    "Luigi",
    "Eugênio",
    "Bento",
    "Edson",
    "Xerxes",
    "Leandro",
    "Kaique",
    "Armando",
    "Nivaldo",
    "Jeferson",
    "Ryan",
    "Arnaldo",
    "Rodrigo",
    "Severino",
    "Fabiano",
    "Tomáz",
    "Noah",
    "Elias",
    "Rafael",
    "Yago",
    "Pablo",
    "Willian",
    "Heitor",
    "Reinaldo",
    "Everaldo",
    "Luiz",
    "Jack",
    "Alisson",
    "Hércules",
    "Vicente",
    "Erick",
    "Dionísio",
    "Inácio",
    "Leonardo",
    "Adílson",
    "Bóris",
    "Ciro",
    "Alex",
    "Ali",
    "Fernando",
    "Chico",
    "Ian",
    "Luís",
    "Benjamin",
    "Alan",
    "Adônis",
    "Milton",
    "Antonio",
    "Quirino",
    "Isaías",
    "Antônio",
    "Jorge",
    "Manuel",
    "Dário",
    "Tiago",
    "Jairo",
    "Uribe",
    "Hilton",
    "Danilo",
    "Joaquim",
    "Nilton",
    "Aloísio",
    "Luciano",
    "Roberto",
    "Fred",
    "Geraldo",
    "Alberto",
    "Otaviano",
    "Victor",
    "Igor",
    "Daniel",
    "Caio",
    "Eliel",
    "Felipe",
    "Flávio",
    "Jardel",
    "Alessandre",
    "Guilherme",
    "Kauê",
    "Sérgio",
    "Ivan",
    "Benedito",
    "Júlio",
    "Elano",
    "Mariano",
    "Reginaldo",
    "Ramon",
    "Ismael",
    "Giovanni",
    "José",
    "Ricardo",
    "Rivaldo",
    "Rodolfo",
    "Valter",
    "Nicolas",
    "Anderson",
    "Alfredo",
    "Patrick",
    "Túlio",
    "Artur",
    "Pedro",
    "Maurício",
    "Emanuel",
    "Thales",
    "Jason",
    "Isaac",
    "Táles",
    "Joao",
    "Silvair",
    "Isac",
    "Jonathas",
    "Lucas",
    "Altino",
    "Gustavo",
    "Nicolau",
    "Márcio",
    "Ney",
    "Filipe",
    "Enrico",
    "Jonathan",
    "Rogério",
    "Oliver",
    "Edinaldo",
    "Batista",
    "Vinicius",
    "Bryan",
    "Jonas",
    "Carlos",
    "Félix",
    "Áureo",
    "Laerte",
    "Mateus",
    "Miguel",
    "Israel",
    "Luan",
    "Eustáquio",
    "Saulo",
    "Marlon",
    "Omar",
    "Washington",
    "Cleberson",
    "Cristiano",
    "Avelino",
    "Renan",
    "Iago",
    "Andre",
    "Joel",
    "Juliano",
    "Fagner",
    "Diego",
    "Nelson",
    "Diogo",
    "Nilo",
    "Michel",
    "Marco",
    "Eric",
    "João",
    "Osório",
    "Oséas",
    "David",
    "Osvaldo",
    "Jair",
    "Bernardo",
    "Charles",
    "Thomas",
    "Robert",
    "Otavio",
    "Caua",
    "Robson",
    "Hélio",
    "Wilson",
    "Cléber",
    "Eduardo",
    "Luke",
    "Quico",
    "Aldo",
    "Celso",
    "Hildebrando",
    "Everton",
    "Yuri",
    "Ezequiel",
    "César",
    "Cícero",
    "Humberto",
    "Edu",
    "Orlando",
    "Juan",
    "Jacinto",
    "Walter",
    "Altair",
    "Jesus",
    "Enzo",
    "Bartolomeu",
    "Calebe",
    "Marcos",
    "Albano",
    "Mike",
    "Itamar",
    "Ederson",
    "Leopoldo",
    "André",
    "Dante",
    "Hugo",
    "Toninho",
    "Moisés",
    "Raul",
    "Edivaldo",
    "Lúcio",
    "Francisco",
    "Marciano",
    "Raí",
    "Wellington",
    "Heron",
    "Vinícius",
    "Abílio",
    "Jânio",
    "Wagner",
    "Jackson",
    "Wally",
    "Pietro",
    "Fábio",
    "Nathan",
    "Elói",
    "Henrique",
    "Albino",
    "Adriano",
    "Laércio",
    "Kim",
    "Anthony",
    "Lorenzo",
    "Ayrton",
    "Cirilo",
    "Thiago",
    "Aurélio",
    "Gilmar",
    "Denis",
    "Sandro",
    "Leo",
    "Jean",
    "Otávio",
    "Arthur",
    "Benicio",
    "Amarildo",
    "Lino",
    "Max",
    "Levi",
    "Mário",
    "Olavo",
    "Ângelo",
    "Cauê",
    "Paulo",
    "Renato",
    "Davi",
    "Marcelo",
    "Alexandre",
    "Augusto",
    "Theo",
    "Junior",
    "Breno",
    "Zeca",
    "Micael",
    "Álvaro",
    "Sebastião",
    "Wesley",
    "Anakin",
    "Romildo",
    "Manoel",
    "Matheus",
    "Vitor",
    "Hamilton",
    "Plínio",
    "Jaziel",
    "Roberval",
    "Emanoel",
    "Freddy",
    "Demilson",
    "Gilson",
    "Murilo",
    "Roger",
    "Giuseppe",
    "Sílvio",
    "Barnabé",
    "Domingos",
    "Gabriel",
    "Martinho",
    "Martin",
    "Kevin",
    "Helder",
    "Décio",
    "Xavier",
    "Simão",
    "Lucca",
    "Fabrício",
    "Ademar",
    "Camilo",
    "Baltazar",
    "Aécio",
    "Moacyr",
    "Bruno",
    "Ronaldo",
    "Luccas",
    "Frederico",
    "Emílio",
    "Estevão",
    "Beto",
    "Samuel",
    "Karl",
]



from setuptools import setup

with open('README.md', 'r') as f:
    long_description = f.read()

setup(
    name='pt_name_gen',
    version='0.2.2',
    description='A name generator in Portuguese. Um gerador de nomes em português.',
    author='Victor Figueredo',
    packages=['pt_name_gen'],
    long_description=long_description,
    long_description_content_type='text/markdown',
    install_requires=[],
    entry_points={
        'console_scripts': [
            'pt_name_gen=pt_name_gen:main'
        ]
    }
)
